@@ -3,13 +3,13 @@
 /* URL: http://www1.ttcn.ne.jp/~kaneto */
 
 /*WIN32DLL*/
-/* $B$3$A$i$N%P!<%8%g%s$b99?7$7$F$/$@$5$$!#(B */
-#define NKF_VERSIONW L"2.1.1"
-/* NKF_VERSION $B$N%o%$%IJ8;z(B */
-#define DLL_VERSION   "2.1.1.0 2"
-/* DLL$B$,JV$9(B */
-#define DLL_VERSIONW L"2.1.1.0 2"
-/* DLL$B$,JV$9(B DLL_VERSION $B$N%o%$%IJ8;z(B */
+/* ̃o[WXVĂB */
+#define NKF_VERSIONW L"2.1.3"
+/* NKF_VERSION ̃Ch */
+#define DLL_VERSION   "2.1.3.0 2"
+/* DLLԂ */
+#define DLL_VERSIONW L"2.1.3.0 2"
+/* DLLԂ DLL_VERSION ̃Ch */
 
 /* nkf32.dll main */
 #include <windows.h>
@@ -93,21 +93,21 @@ int dllprintf(FILE *fp,char *fmt,...)
 /** Network Kanji Filter. (PDS Version)
 ************************************************************************
 ** Copyright (C) 1987, Fujitsu LTD. (Itaru ICHIKAWA)
-** $BO"Mm@h!'(B $B!J3t!KIY;NDL8&5f=j!!%=%U%H#38&!!;T@n!!;j(B 
-** $B!J(BE-Mail Address: ichikawa@flab.fujitsu.co.jp$B!K(B
+** AF ijxmʌ@\tgR@s@ 
+** iE-Mail Address: ichikawa@flab.fujitsu.co.jpj
 ** Copyright (C) 1996,1998
 ** Copyright (C) 2002
-** $BO"Mm@h!'(B $BN05eBg3X>pJs9)3X2J(B $B2OLn(B $B??<#(B  mime/X0208 support
-** $B!J(BE-Mail Address: kono@ie.u-ryukyu.ac.jp$B!K(B
-** $BO"Mm@h!'(B COW for DOS & Win16 & Win32 & OS/2
-** $B!J(BE-Mail Address: GHG00637@niftyserve.or.p$B!K(B
+** AF wHw ͖ ^  mime/X0208 support
+** iE-Mail Address: kono@ie.u-ryukyu.ac.jpj
+** AF COW for DOS & Win16 & Win32 & OS/2
+** iE-Mail Address: GHG00637@niftyserve.or.pj
 **
-**    $B$3$N%=!<%9$N$$$+$J$kJ#<L!$2~JQ!$=$@5$b5vBz$7$^$9!#$?$@$7!"(B
-**    $B$=$N:]$K$O!"C/$,9W8%$7$?$r<($9$3$NItJ,$r;D$9$3$H!#(B
-**    $B:FG[I[$d;(;o$NIUO?$J$I$NLd$$9g$o$;$bI,MW$"$j$^$;$s!#(B
-**    $B1DMxMxMQ$b>e5-$KH?$7$J$$HO0O$G5v2D$7$^$9!#(B
-**    $B%P%$%J%j$NG[I[$N:]$K$O(Bversion message$B$rJ]B8$9$k$3$H$r>r7o$H$7$^$9!#(B
-**    $B$3$N%W%m%0%i%`$K$D$$$F$OFC$K2?$NJ]>Z$b$7$J$$!"0-$7$+$i$:!#(B
+**    ̃\[X̂Ȃ镡ʁCρCC܂BA
+**    ̍ۂɂ́ANv̕cƁB
+**    ĔzzG̕t^Ȃǂ̖₢킹Kv܂B
+**    cpLɔȂ͈͂ŋ܂B
+**    oCi̔zz̍ۂɂversion messageۑ邱ƂƂ܂B
+**    ̃vOɂĂ͓ɉ̕ۏ؂ȂA炸B
 **
 **    Everyone is permitted to do anything on this program 
 **    including copying, modifying, improving,
@@ -212,7 +212,7 @@ print_guessed_codeW (filename)
 #endif /*UNICODESUPPORT*/
 
 /**
- ** $B%Q%C%A@):n<T(B
+ ** pb`
  **  void@merope.pleiades.or.jp (Kusakabe Youichi)
  **  NIDE Naoyuki <nide@ics.nara-wu.ac.jp>
  **  ohta@src.ricoh.co.jp (Junn Ohta)
@@ -435,7 +435,7 @@ void CALLBACK ToMime(LPSTR outStr ,LPCSTR inStr)
 int CALLBACK NkfGetKanjiCode(VOID)
 {
     int iCode=0;
-    /* if(iconv == s_iconv)iCode=0; */ /* 0:$B%7%U%H(BJIS */
+    /* if(iconv == s_iconv)iCode=0; */ /* 0:VtgJIS */
     if(iconv == w_iconv)iCode=3; /* UTF-8 */
     else if(iconv == w_iconv16){
         if(input_endian == ENDIAN_BIG)iCode=5; /* 5:UTF-16BE */
@@ -782,7 +782,7 @@ unsigned char buff[65536];
 unsigned char buff2[65536];
 unsigned char buff3[65536];
 unsigned char buff4[65536];
-char *code[] = {"$B%7%U%H(BJIS","EUC","ISO-2022-JP","UTF-8","UTF-16LE","UTF-16BE"};
+char *code[] = {"VtgJIS","EUC","ISO-2022-JP","UTF-8","UTF-16LE","UTF-16BE"};
 
     int n;
     BOOL sts;
